@@ -13,7 +13,7 @@ def test():
     if log.is_file():
         os.remove(log)  # pragma: no cover
     response = client.post("/send-notification/foo@example.com")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"message": "Notification sent in the background"}
     with open("./log.txt") as f:
         assert "notification for foo@example.com: some notification" in f.read()
