@@ -2,8 +2,8 @@ import gzip
 import json
 
 import pytest
-from starlette.requests import Request
-from starlette.testclient import TestClient
+from fastapi import Request
+from fastapi.testclient import TestClient
 
 from custom_request_and_route.tutorial001 import app
 
