@@ -18,7 +18,7 @@ def test_exception_handler_body_access():
             "body": '{"numbers": [1, 2, 3]}',
             "errors": [
                 {
-                    "loc": ["body", "numbers"],
+                    "loc": ["body"],
                     "msg": "value is not a valid list",
                     "type": "type_error.list",
                 }
