@@ -98,7 +98,7 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
@@ -112,7 +112,7 @@ def test_post_user():
             "full_name": "Grave Dohl",
         },
     )
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {
         "username": "foo",
         "email": "foo@example.com",
