@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 import pytest
 from fastapi import FastAPI
@@ -10,7 +10,7 @@ app = FastAPI()
 
 class Item(BaseModel):
     name: str
-    price: float = None
+    price: Optional[float] = None
     owner_ids: List[int] = None
 
 
