@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 import pytest
 from fastapi import FastAPI
@@ -12,7 +12,7 @@ app = FastAPI()
 @dataclass
 class Item:
     name: str
-    price: float = None
+    price: Optional[float] = None
     owner_ids: List[int] = None
 
 
